@@ -4,6 +4,8 @@
  * Copyright (C) 2002, 2003  CodeFactory AB
  * Copyright (C) 2003, 2004 Red Hat, Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -103,6 +105,9 @@ void             dbus_g_thread_init (void);
 
 DBusGConnection* dbus_g_connection_open (const gchar  *address,
                                          GError      **error);
+DBusGConnection* dbus_g_connection_open_private (const gchar  *address,
+                                                 GMainContext *context,
+                                                 GError      **error);
 DBusGConnection* dbus_g_bus_get         (DBusBusType   type,
                                          GError      **error);
 DBusGConnection* dbus_g_bus_get_private (DBusBusType   type,
@@ -159,7 +164,7 @@ void       dbus_glib_global_set_disable_legacy_property_access (void);
 void       dbus_g_object_type_install_info     (GType                 object_type,
                                                 const DBusGObjectInfo *info);
 
-void       dbus_g_object_type_register_shadow_property (GType         object_type,
+void       dbus_g_object_type_register_shadow_property (GType         iface_type,
                                                         const char    *dbus_prop_name,
                                                         const char    *shadow_prop_name);
 
@@ -220,11 +225,13 @@ typedef struct _DBusGProxyClass  DBusGProxyClass;
 
 struct _DBusGProxy
 {
+  /*< private >*/
   GObject parent;
 };
 
 struct _DBusGProxyClass
 {
+  /*< private >*/
   GObjectClass parent_class;  /**< Parent class */
 };
 
@@ -245,10 +252,10 @@ DBusGProxy*       dbus_g_proxy_new_for_name_owner    (DBusGConnection   *connect
                                                       GError           **error);
 DBusGProxy*       dbus_g_proxy_new_from_proxy        (DBusGProxy        *proxy,
                                                       const char        *iface,
-                                                      const char        *path_name);
+                                                      const char        *path);
 DBusGProxy*       dbus_g_proxy_new_for_peer          (DBusGConnection   *connection,
-                                                      const char        *path_name,
-                                                      const char        *interface_name);
+                                                      const char        *path,
+                                                      const char        *iface);
 
 void              dbus_g_proxy_set_interface         (DBusGProxy        *proxy,
 						      const char        *interface_name);
@@ -288,7 +295,7 @@ void              dbus_g_proxy_call_no_reply         (DBusGProxy        *proxy,
 DBusGProxyCall *  dbus_g_proxy_begin_call            (DBusGProxy        *proxy,
                                                       const char        *method,
 						      DBusGProxyCallNotify notify,
-						      gpointer           data,
+						      gpointer           user_data,
 						      GDestroyNotify     destroy,
                                                       GType              first_arg_type,
                                                       ...);
@@ -324,6 +331,8 @@ void              dbus_g_method_return               (DBusGMethodInvocation *con
 
 void              dbus_g_method_return_error         (DBusGMethodInvocation *context, const GError *error);
 
+DBusGConnection * dbus_g_method_invocation_get_g_connection (DBusGMethodInvocation *context);
+
 /* Probably possible to replace this with a closure */
 typedef struct {
   GCallback cb;
